@@ -55,4 +55,8 @@ test_gz_16_rsyncable() {
   assertWorksWithTarball $SAMPLES/tarballs/libinotify-kqueue-1.6rsyncable_20120419.orig.tar.gz
 }
 
+test_escaping() {
+  assertWorksWithTarball $SAMPLES/tarballs/systemd_239.orig.tar.gz
+}
+
 . shunit2
